@@ -255,7 +255,7 @@ class Network:
             node_label=node_label,
             link_label=link_label,
             interval=interval,
-            repeat=repeat,
+            repeat=repeat
         )
 
     def bokehplot(
